﻿namespace SampelProject
{
    using System;
    using System.Collections.Generic;
    using System.Data;
    using System.Drawing;
    using System.Net;
    using System.Windows.Forms;
    using Infragistics.Win;
    using Infragistics.Win.FormattedLinkLabel;
    using Infragistics.Win.UltraWinGrid;

    public partial class Form1 : Form
    {
        private static Dictionary<string, Image> _iconList;
        public Form1()
        {
            InitIconList();
            this.InitializeComponent();
            this.Load += Form1_Load;
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            var data = this.GetData();
            this.ultraGrid1.SetDataBinding(data, data.TableName);


            this.ultraGrid1.DisplayLayout.Bands[0].Columns.Add("Formatted Column");

            this.ultraGrid1.DisplayLayout.Bands[0].Columns["Formatted Column"].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.FormattedTextEditor;
            this.ultraGrid1.DisplayLayout.Bands[0].Columns["Formatted Column"].CellAppearance.TextTrimming = TextTrimming.None;
            this.ultraGrid1.DisplayLayout.Bands[0].Columns["Formatted Column"].Width = 200;

            this.ultraGrid1.DisplayLayout.Bands[0].Columns.Add("Icon Column");
            this.ultraGrid1.DisplayLayout.Bands[0].Columns["Icon Column"].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.FormattedTextEditor;
            this.ultraGrid1.DisplayLayout.Bands[0].Columns["Icon Column"].CellAppearance.TextTrimming = TextTrimming.None;
            this.ultraGrid1.DisplayLayout.Bands[0].Columns["Icon Column"].Width = 300;

            this.ultraGrid1.DisplayLayout.Bands[0].Columns.Add("Icon1 Column");
            this.ultraGrid1.DisplayLayout.Bands[0].Columns["Icon1 Column"].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.FormattedTextEditor;
            this.ultraGrid1.DisplayLayout.Bands[0].Columns["Icon1 Column"].CellAppearance.TextTrimming = TextTrimming.None;

            int i = 0;
            foreach (var row in this.ultraGrid1.DisplayLayout.Rows)
            {
                var formattedText = "<b>" + HtmlEncode("Bolded Text") + "</b>" + "Normal text";

                int mod = i % 10;

                formattedText = string.Format("{0}<br/> {1}", formattedText, "Normal text Normal text Normal text Normal text Normal text Normal text Normal text Normal text");
                row.Cells[5].Value = formattedText;

                formattedText = string.Format("{0}<br/> Icon1 {1}", formattedText, GetImageString(mod.ToString()));
                row.Cells[6].Value = formattedText;
                row.Cells[7].Value = formattedText;

                i++;
            }
        }

        private void UltraGrid1_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            ultraGrid1.DisplayLayout.ScrollStyle = Infragistics.Win.UltraWinGrid.ScrollStyle.Immediate;

            ultraGrid1.DisplayLayout.Override.HeaderStyle = HeaderStyle.Standard;

            ultraGrid1.DisplayLayout.Override.RowSizing = RowSizing.AutoFree;


            ultraGrid1.DisplayLayout.Override.RowSizingAutoMaxLines = (int)(ultraGrid1.Height / 21);

            ultraGrid1.DisplayLayout.Override.CellMultiLine = DefaultableBoolean.True;
            ultraGrid1.DisplayLayout.MaxColScrollRegions = 2;
            ultraGrid1.DisplayLayout.MaxRowScrollRegions = 2;

            ultraGrid1.DisplayLayout.ScrollBounds = ScrollBounds.ScrollToFill;


            ultraGrid1.DisplayLayout.Override.RowAppearance.FontData.SizeInPoints = 9;
            ultraGrid1.DisplayLayout.Override.RowAppearance.BackColorAlpha = Alpha.Opaque;
            ultraGrid1.DisplayLayout.Override.RowAppearance.ForegroundAlpha = Alpha.Opaque;
            ultraGrid1.DisplayLayout.Override.RowAppearance.ImageAlpha = Alpha.Opaque;

            ultraGrid1.DisplayLayout.Override.BorderStyleRow = UIElementBorderStyle.Solid;
            ultraGrid1.DisplayLayout.Override.BorderStyleCell = UIElementBorderStyle.None;
            ultraGrid1.DisplayLayout.Override.AllowRowFiltering = DefaultableBoolean.False;


            ultraGrid1.DisplayLayout.Override.AllowAddNew = AllowAddNew.No;
            ultraGrid1.DisplayLayout.Override.AllowDelete = DefaultableBoolean.False;
            ultraGrid1.DisplayLayout.Override.AllowRowLayoutCellSizing = RowLayoutSizing.None;
            ultraGrid1.DisplayLayout.Override.CellClickAction = CellClickAction.RowSelect;
            ultraGrid1.DisplayLayout.Override.HeaderClickAction = HeaderClickAction.SortMulti;
            ultraGrid1.DisplayLayout.Override.CellPadding = 0;
            ultraGrid1.DisplayLayout.Override.RowSelectors = DefaultableBoolean.False;

            ultraGrid1.DisplayLayout.InterBandSpacing = 0;
            ultraGrid1.DisplayLayout.Override.RowSpacingAfter = 0;
            ultraGrid1.DisplayLayout.Override.SelectTypeRow = SelectType.Single;

            ultraGrid1.DisplayLayout.Override.AllowColSizing = AllowColSizing.Free;
            ultraGrid1.DisplayLayout.Override.AllowColMoving = AllowColMoving.NotAllowed;
            ultraGrid1.DisplayLayout.Override.AllowColSwapping = AllowColSwapping.NotAllowed;

            ultraGrid1.DisplayLayout.AutoFitStyle = AutoFitStyle.None;
        }

        private static string GetImageString(string iconKey)
        {
            string encodedImg = FormattedLinkEditor.EncodeImage(_iconList[iconKey]);
            string iconString = string.Format("<img data= \"{0}\" Align =\"bottom\" /> ", encodedImg);

            return iconString;
        }

        private static void InitIconList()
        {
            _iconList = new Dictionary<string, Image>();
            for (int i = 0; i < 10; i++)
            {
                _iconList.Add(i.ToString(), Bitmap.FromFile(@"../../images/" + i.ToString() + ".png"));
            }
        }

        public static string HtmlEncode(string s)
        {
            if (!string.IsNullOrEmpty(s))
            {
                s = WebUtility.HtmlEncode(s);


                s = s.Replace(" ", "&edsp;");
            }

            return s;
        }

        private DataTable GetData(int rows = 2000, int cols = 5)
        {
            DataTable dt = new DataTable();

            for (int col = 0; col < cols; col++)
            {
                dt.Columns.Add(string.Format("Column #{0}", col + 1));
            }

            for (int row = 0; row < rows; row++)
            {
                DataRow addRow = dt.NewRow();
                foreach (DataColumn column in dt.Columns)
                {
                    addRow[column] = string.Format("{0}.{1}", row + 1, column.Ordinal + 1);
                }

                dt.Rows.Add(addRow);
            }

            return dt;
        }
    }
}
